pub fn current_thread<S>(schema: S) -> CurrentThread<S>where
S: Schema,Expand description
Create a GraphQL executor from the specified RootNode.
The endpoint created by this executor will execute the GraphQL queries on the current thread.
pub fn current_thread<S>(schema: S) -> CurrentThread<S>where
S: Schema,Create a GraphQL executor from the specified RootNode.
The endpoint created by this executor will execute the GraphQL queries on the current thread.